@@ -14,7 +14,8 @@ for i in range(N):
         view[i, j, 2] = int(j/N*255)
         view[i, j, 3] = 255
 
-p = figure(x_range=(0,10), y_range=(0,10))
+p = figure(tooltips=[("x", "$x"), ("y", "$y"), ("value", "@image")])
+p.x_range.range_padding = p.y_range.range_padding = 0
 
 # must give a vector of images
 p.image_rgba(image=[img], x=0, y=0, dw=10, dh=10)
