@@ -12,7 +12,7 @@ source = ColumnDataSource(dict(x=x, y=y))
 
 plot = Plot(
     title=None, plot_width=300, plot_height=300,
-    h_symmetry=False, v_symmetry=False, min_border=0, toolbar_location=None)
+    min_border=0, toolbar_location=None)
 
 glyph = Line(x="x", y="y", line_color="#f46d43", line_width=6, line_alpha=0.6)
 plot.add_glyph(source, glyph)
