@@ -20,6 +20,7 @@ import pytest ; pytest
 # Standard library imports
 import os
 from subprocess import PIPE, Popen
+from sys import executable
 
 # External imports
 
@@ -63,7 +64,7 @@ def test_python_execution_with_OO():
     test_env = os.environ.copy()
     test_env['BOKEH_DOCS_MISSING_API_KEY_OK'] = 'yes'
 
-    proc = Popen(["python", "-OO", "-"], stdout=PIPE, stdin=PIPE, env=test_env)
+    proc = Popen([executable, "-OO", "-"], stdout=PIPE, stdin=PIPE, env=test_env)
     proc.communicate("\n".join(imports).encode("utf-8"))
     proc.wait()
 
